# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_conditions/v1/tick_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/tick_conditions/v1/tick_conditions.proto\x12-systemathics.apis.services.tick_conditions.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x8a\x01\n\x15TickConditionsRequest\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierH\x00\x12\x12\n\x08\x65xchange\x18\x02 \x01(\tH\x00\x12\x10\n\x06source\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"`\n\x16TickConditionsResponse\x12\x46\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.tick_conditions.v1.Condition\"b\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x0f\n\x07regular\x18\x04 \x01(\x08\x12\x0f\n\x07\x61uction\x18\x05 \x01(\x08\x32\xb7\x01\n\x15TickConditionsService\x12\x9d\x01\n\x0eTickConditions\x12\x44.systemathics.apis.services.tick_conditions.v1.TickConditionsRequest\x1a\x45.systemathics.apis.services.tick_conditions.v1.TickConditionsResponseb\x06proto3')



_TICKCONDITIONSREQUEST = DESCRIPTOR.message_types_by_name['TickConditionsRequest']
_TICKCONDITIONSRESPONSE = DESCRIPTOR.message_types_by_name['TickConditionsResponse']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
TickConditionsRequest = _reflection.GeneratedProtocolMessageType('TickConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsRequest)
  })
_sym_db.RegisterMessage(TickConditionsRequest)

TickConditionsResponse = _reflection.GeneratedProtocolMessageType('TickConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsResponse)
  })
_sym_db.RegisterMessage(TickConditionsResponse)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

_TICKCONDITIONSSERVICE = DESCRIPTOR.services_by_name['TickConditionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKCONDITIONSREQUEST._serialized_start=170
  _TICKCONDITIONSREQUEST._serialized_end=308
  _TICKCONDITIONSRESPONSE._serialized_start=310
  _TICKCONDITIONSRESPONSE._serialized_end=406
  _CONDITION._serialized_start=408
  _CONDITION._serialized_end=506
  _TICKCONDITIONSSERVICE._serialized_start=509
  _TICKCONDITIONSSERVICE._serialized_end=692
# @@protoc_insertion_point(module_scope)
