# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import raw_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_raw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a*systemathics/apis/type/shared/v1/raw.proto\"\x9f\x01\n\x0eTickRawRequest\x12I\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevel\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\x8d\x01\n\x0fTickRawResponse\x12\x34\n\x03raw\x18\x01 \x01(\x0b\x32%.systemathics.apis.type.shared.v1.RawH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x86\x01\n\x0eTickRawService\x12t\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse0\x01\x62\x06proto3')



_TICKRAWREQUEST = DESCRIPTOR.message_types_by_name['TickRawRequest']
_TICKRAWRESPONSE = DESCRIPTOR.message_types_by_name['TickRawResponse']
TickRawRequest = _reflection.GeneratedProtocolMessageType('TickRawRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawRequest)
  })
_sym_db.RegisterMessage(TickRawRequest)

TickRawResponse = _reflection.GeneratedProtocolMessageType('TickRawResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse)
  })
_sym_db.RegisterMessage(TickRawResponse)

_TICKRAWSERVICE = DESCRIPTOR.services_by_name['TickRawService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKRAWREQUEST._serialized_start=338
  _TICKRAWREQUEST._serialized_end=497
  _TICKRAWRESPONSE._serialized_start=500
  _TICKRAWRESPONSE._serialized_end=641
  _TICKRAWSERVICE._serialized_start=644
  _TICKRAWSERVICE._serialized_end=778
# @@protoc_insertion_point(module_scope)
