# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import mbl_market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mbl__market__book__updates__pb2
from systemathics.apis.type.shared.v1 import mbo_market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mbo__market__book__updates__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/tick/v1/tick_updates.proto\x12\"systemathics.apis.services.tick.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a>systemathics/apis/type/shared/v1/mbl_market_book_updates.proto\x1a>systemathics/apis/type/shared/v1/mbo_market_book_updates.proto\"\xb7\x01\n\x12TickUpdatesRequest\x12I\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevel\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"\xd4\x02\n\x13TickUpdatesResponse\x12O\n\x0e\x66ields_updates\x18\x01 \x01(\x0b\x32\x35.systemathics.apis.type.shared.v1.MarketFieldsUpdatesH\x00\x12R\n\x10mbl_book_updates\x18\x02 \x01(\x0b\x32\x36.systemathics.apis.type.shared.v1.MblMarketBookUpdatesH\x00\x12R\n\x10mbo_book_updates\x18\x03 \x01(\x0b\x32\x36.systemathics.apis.type.shared.v1.MboMarketBookUpdatesH\x00\x12\x39\n\x07mapping\x18\x04 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x97\x01\n\x12TickUpdatesService\x12\x80\x01\n\x0bTickUpdates\x12\x36.systemathics.apis.services.tick.v1.TickUpdatesRequest\x1a\x37.systemathics.apis.services.tick.v1.TickUpdatesResponse0\x01\x62\x06proto3')



_TICKUPDATESREQUEST = DESCRIPTOR.message_types_by_name['TickUpdatesRequest']
_TICKUPDATESRESPONSE = DESCRIPTOR.message_types_by_name['TickUpdatesResponse']
TickUpdatesRequest = _reflection.GeneratedProtocolMessageType('TickUpdatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesRequest)
  })
_sym_db.RegisterMessage(TickUpdatesRequest)

TickUpdatesResponse = _reflection.GeneratedProtocolMessageType('TickUpdatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesResponse)
  })
_sym_db.RegisterMessage(TickUpdatesResponse)

_TICKUPDATESSERVICE = DESCRIPTOR.services_by_name['TickUpdatesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKUPDATESREQUEST._serialized_start=488
  _TICKUPDATESREQUEST._serialized_end=671
  _TICKUPDATESRESPONSE._serialized_start=674
  _TICKUPDATESRESPONSE._serialized_end=1014
  _TICKUPDATESSERVICE._serialized_start=1017
  _TICKUPDATESSERVICE._serialized_end=1168
# @@protoc_insertion_point(module_scope)
