# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import quote_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/limit.proto\x12 systemathics.apis.type.shared.v1\x1a,systemathics/apis/type/shared/v1/quote.proto\"l\n\x05Limit\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\x12\x37\n\x06quotes\x18\x04 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Quoteb\x06proto3')



_LIMIT = DESCRIPTOR.message_types_by_name['Limit']
Limit = _reflection.GeneratedProtocolMessageType('Limit', (_message.Message,), {
  'DESCRIPTOR' : _LIMIT,
  '__module__' : 'systemathics.apis.type.shared.v1.limit_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Limit)
  })
_sym_db.RegisterMessage(Limit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIMIT._serialized_start=128
  _LIMIT._serialized_end=236
# @@protoc_insertion_point(module_scope)
