# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/topology/v1/topologies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7systemathics/apis/services/topology/v1/topologies.proto\x12&systemathics.apis.services.topology.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/level.proto\"\xb7\x02\n\x11TopologiesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12P\n\x0bgranularity\x18\x03 \x01(\x0e\x32;.systemathics.apis.services.topology.v1.TopologyGranularity\x12*\n\x05start\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"f\n\rTopologyEntry\x12 \n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x1e\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x13\n\x0bticks_count\x18\x03 \x01(\x04\"n\n\x12TopologiesResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v1.TopologyEntry\x12\x10\n\x08has_more\x18\x02 \x01(\x08*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\x99\x01\n\x11TopologiesService\x12\x83\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v1.TopologiesRequest\x1a:.systemathics.apis.services.topology.v1.TopologiesResponseb\x06proto3')

_TOPOLOGYGRANULARITY = DESCRIPTOR.enum_types_by_name['TopologyGranularity']
TopologyGranularity = enum_type_wrapper.EnumTypeWrapper(_TOPOLOGYGRANULARITY)
TOPOLOGY_GRANULARITY_UNSPECIFIED = 0
TOPOLOGY_GRANULARITY_DAILY = 1
TOPOLOGY_GRANULARITY_WEEKLY = 2
TOPOLOGY_GRANULARITY_MONTHLY = 3
TOPOLOGY_GRANULARITY_QUATERLY = 4
TOPOLOGY_GRANULARITY_YEARLY = 5


_TOPOLOGIESREQUEST = DESCRIPTOR.message_types_by_name['TopologiesRequest']
_TOPOLOGYENTRY = DESCRIPTOR.message_types_by_name['TopologyEntry']
_TOPOLOGIESRESPONSE = DESCRIPTOR.message_types_by_name['TopologiesResponse']
TopologiesRequest = _reflection.GeneratedProtocolMessageType('TopologiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESREQUEST,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesRequest)
  })
_sym_db.RegisterMessage(TopologiesRequest)

TopologyEntry = _reflection.GeneratedProtocolMessageType('TopologyEntry', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYENTRY,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologyEntry)
  })
_sym_db.RegisterMessage(TopologyEntry)

TopologiesResponse = _reflection.GeneratedProtocolMessageType('TopologiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESRESPONSE,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesResponse)
  })
_sym_db.RegisterMessage(TopologiesResponse)

_TOPOLOGIESSERVICE = DESCRIPTOR.services_by_name['TopologiesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPOLOGYGRANULARITY._serialized_start=783
  _TOPOLOGYGRANULARITY._serialized_end=1009
  _TOPOLOGIESREQUEST._serialized_start=253
  _TOPOLOGIESREQUEST._serialized_end=564
  _TOPOLOGYENTRY._serialized_start=566
  _TOPOLOGYENTRY._serialized_end=668
  _TOPOLOGIESRESPONSE._serialized_start=670
  _TOPOLOGIESRESPONSE._serialized_end=780
  _TOPOLOGIESSERVICE._serialized_start=1012
  _TOPOLOGIESSERVICE._serialized_end=1165
# @@protoc_insertion_point(module_scope)
