# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/sustainability/v1/sustainability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/sustainability/v1/sustainability.proto\x12,systemathics.apis.services.sustainability.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"Y\n\x15SustainabilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\"d\n\x16SustainabilityResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.sustainability.v1.Sustainability\"\x8a\x01\n\x0eSustainability\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0b\n\x03min\x18\x06 \x01(\x01\x12\x0b\n\x03max\x18\x07 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t2\xb5\x01\n\x15SustainabilityService\x12\x9b\x01\n\x0eSustainability\x12\x43.systemathics.apis.services.sustainability.v1.SustainabilityRequest\x1a\x44.systemathics.apis.services.sustainability.v1.SustainabilityResponseb\x06proto3')



_SUSTAINABILITYREQUEST = DESCRIPTOR.message_types_by_name['SustainabilityRequest']
_SUSTAINABILITYRESPONSE = DESCRIPTOR.message_types_by_name['SustainabilityResponse']
_SUSTAINABILITY = DESCRIPTOR.message_types_by_name['Sustainability']
SustainabilityRequest = _reflection.GeneratedProtocolMessageType('SustainabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYREQUEST,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityRequest)
  })
_sym_db.RegisterMessage(SustainabilityRequest)

SustainabilityResponse = _reflection.GeneratedProtocolMessageType('SustainabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityResponse)
  })
_sym_db.RegisterMessage(SustainabilityResponse)

Sustainability = _reflection.GeneratedProtocolMessageType('Sustainability', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITY,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.Sustainability)
  })
_sym_db.RegisterMessage(Sustainability)

_SUSTAINABILITYSERVICE = DESCRIPTOR.services_by_name['SustainabilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUSTAINABILITYREQUEST._serialized_start=166
  _SUSTAINABILITYREQUEST._serialized_end=255
  _SUSTAINABILITYRESPONSE._serialized_start=257
  _SUSTAINABILITYRESPONSE._serialized_end=357
  _SUSTAINABILITY._serialized_start=360
  _SUSTAINABILITY._serialized_end=498
  _SUSTAINABILITYSERVICE._serialized_start=501
  _SUSTAINABILITYSERVICE._serialized_end=682
# @@protoc_insertion_point(module_scope)
