# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_fields_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import field_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/type/shared/v1/market_fields_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a,systemathics/apis/type/shared/v1/field.proto\"\xab\x01\n\x13MarketFieldsUpdates\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x44\n\x07updates\x18\x04 \x03(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketFieldUpdate\"\xd4\x01\n\x11MarketFieldUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x36\n\x05\x66ield\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Field\x12\x14\n\nlong_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x42\x07\n\x05valueb\x06proto3')



_MARKETFIELDSUPDATES = DESCRIPTOR.message_types_by_name['MarketFieldsUpdates']
_MARKETFIELDUPDATE = DESCRIPTOR.message_types_by_name['MarketFieldUpdate']
MarketFieldsUpdates = _reflection.GeneratedProtocolMessageType('MarketFieldsUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDSUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldsUpdates)
  })
_sym_db.RegisterMessage(MarketFieldsUpdates)

MarketFieldUpdate = _reflection.GeneratedProtocolMessageType('MarketFieldUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldUpdate)
  })
_sym_db.RegisterMessage(MarketFieldUpdate)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MARKETFIELDSUPDATES._serialized_start=257
  _MARKETFIELDSUPDATES._serialized_end=428
  _MARKETFIELDUPDATE._serialized_start=431
  _MARKETFIELDUPDATE._serialized_end=643
# @@protoc_insertion_point(module_scope)
