# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__updates__pb2
from systemathics.apis.type.shared.v1 import book_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/services/tick/v1/tick_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x33systemathics/apis/type/shared/v1/book_updates.proto\x1a\x30systemathics/apis/type/shared/v1/book_data.proto\"\xb7\x02\n\x0fTickBookRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x43\n\x0c\x62ook_updates\x18\x02 \x01(\x0e\x32-.systemathics.apis.type.shared.v1.BookUpdates\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\x12.\n\tmax_depth\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x14\n\x0c\x63ontributors\x18\x06 \x01(\x08\"\x94\x01\n\x10TickBookResponse\x12:\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32*.systemathics.apis.type.shared.v1.BookDataH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x8a\x01\n\x0fTickBookService\x12w\n\x08TickBook\x12\x33.systemathics.apis.services.tick.v1.TickBookRequest\x1a\x34.systemathics.apis.services.tick.v1.TickBookResponse0\x01\x62\x06proto3')



_TICKBOOKREQUEST = DESCRIPTOR.message_types_by_name['TickBookRequest']
_TICKBOOKRESPONSE = DESCRIPTOR.message_types_by_name['TickBookResponse']
TickBookRequest = _reflection.GeneratedProtocolMessageType('TickBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookRequest)
  })
_sym_db.RegisterMessage(TickBookRequest)

TickBookResponse = _reflection.GeneratedProtocolMessageType('TickBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookResponse)
  })
_sym_db.RegisterMessage(TickBookResponse)

_TICKBOOKSERVICE = DESCRIPTOR.services_by_name['TickBookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKBOOKREQUEST._serialized_start=407
  _TICKBOOKREQUEST._serialized_end=718
  _TICKBOOKRESPONSE._serialized_start=721
  _TICKBOOKRESPONSE._serialized_end=869
  _TICKBOOKSERVICE._serialized_start=872
  _TICKBOOKSERVICE._serialized_end=1010
# @@protoc_insertion_point(module_scope)
