# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/daily/v1/daily_vwap.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xad\x01\n\x11\x44\x61ilyVwapsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"R\n\x12\x44\x61ilyVwapsResponse\x12<\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..systemathics.apis.services.daily.v1.DailyVwap\"Z\n\tDailyVwap\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x92\x01\n\x11\x44\x61ilyVwapsService\x12}\n\nDailyVwaps\x12\x36.systemathics.apis.services.daily.v1.DailyVwapsRequest\x1a\x37.systemathics.apis.services.daily.v1.DailyVwapsResponseb\x06proto3')



_DAILYVWAPSREQUEST = DESCRIPTOR.message_types_by_name['DailyVwapsRequest']
_DAILYVWAPSRESPONSE = DESCRIPTOR.message_types_by_name['DailyVwapsResponse']
_DAILYVWAP = DESCRIPTOR.message_types_by_name['DailyVwap']
DailyVwapsRequest = _reflection.GeneratedProtocolMessageType('DailyVwapsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsRequest)
  })
_sym_db.RegisterMessage(DailyVwapsRequest)

DailyVwapsResponse = _reflection.GeneratedProtocolMessageType('DailyVwapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsResponse)
  })
_sym_db.RegisterMessage(DailyVwapsResponse)

DailyVwap = _reflection.GeneratedProtocolMessageType('DailyVwap', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAP,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwap)
  })
_sym_db.RegisterMessage(DailyVwap)

_DAILYVWAPSSERVICE = DESCRIPTOR.services_by_name['DailyVwapsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYVWAPSREQUEST._serialized_start=221
  _DAILYVWAPSREQUEST._serialized_end=394
  _DAILYVWAPSRESPONSE._serialized_start=396
  _DAILYVWAPSRESPONSE._serialized_end=478
  _DAILYVWAP._serialized_start=480
  _DAILYVWAP._serialized_end=570
  _DAILYVWAPSSERVICE._serialized_start=573
  _DAILYVWAPSSERVICE._serialized_end=719
# @@protoc_insertion_point(module_scope)
