# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/level.proto\x12 systemathics.apis.type.shared.v1*K\n\x05Level\x12\x15\n\x11LEVEL_UNSPECIFIED\x10\x00\x12\x10\n\x0cLEVEL_TRADES\x10\x01\x12\x19\n\x15LEVEL_TRADES_AND_BOOK\x10\x02\x62\x06proto3')

_LEVEL = DESCRIPTOR.enum_types_by_name['Level']
Level = enum_type_wrapper.EnumTypeWrapper(_LEVEL)
LEVEL_UNSPECIFIED = 0
LEVEL_TRADES = 1
LEVEL_TRADES_AND_BOOK = 2


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEVEL._serialized_start=82
  _LEVEL._serialized_end=157
# @@protoc_insertion_point(module_scope)
