# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/intraday/v1/intraday_prices.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xef\x01\n\x15IntradayPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x16IntradayPricesResponse\x12\x43\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.intraday.v1.IntradayPrice\"m\n\rIntradayPrice\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\xa9\x01\n\x15IntradayPricesService\x12\x8f\x01\n\x0eIntradayPrices\x12=.systemathics.apis.services.intraday.v1.IntradayPricesRequest\x1a>.systemathics.apis.services.intraday.v1.IntradayPricesResponseb\x06proto3')



_INTRADAYPRICESREQUEST = DESCRIPTOR.message_types_by_name['IntradayPricesRequest']
_INTRADAYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['IntradayPricesResponse']
_INTRADAYPRICE = DESCRIPTOR.message_types_by_name['IntradayPrice']
IntradayPricesRequest = _reflection.GeneratedProtocolMessageType('IntradayPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPricesRequest)
  })
_sym_db.RegisterMessage(IntradayPricesRequest)

IntradayPricesResponse = _reflection.GeneratedProtocolMessageType('IntradayPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPricesResponse)
  })
_sym_db.RegisterMessage(IntradayPricesResponse)

IntradayPrice = _reflection.GeneratedProtocolMessageType('IntradayPrice', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPrice)
  })
_sym_db.RegisterMessage(IntradayPrice)

_INTRADAYPRICESSERVICE = DESCRIPTOR.services_by_name['IntradayPricesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYPRICESREQUEST._serialized_start=290
  _INTRADAYPRICESREQUEST._serialized_end=529
  _INTRADAYPRICESRESPONSE._serialized_start=531
  _INTRADAYPRICESRESPONSE._serialized_end=624
  _INTRADAYPRICE._serialized_start=626
  _INTRADAYPRICE._serialized_end=735
  _INTRADAYPRICESSERVICE._serialized_start=738
  _INTRADAYPRICESSERVICE._serialized_end=907
# @@protoc_insertion_point(module_scope)
