# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_sector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/static_data/v1/static_sector.proto\x12)systemathics.apis.services.static_data.v1\"Q\n\x13StaticSectorRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x04\x63ode\x18\x02 \x01(\tH\x00\x12\x0f\n\x05level\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"z\n\x14StaticSectorResponse\x12>\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.static_data.v1.Level\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"U\n\x05Level\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x12\n\ndefinition\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t2\xa7\x01\n\x13StaticSectorService\x12\x8f\x01\n\x0cStaticSector\x12>.systemathics.apis.services.static_data.v1.StaticSectorRequest\x1a?.systemathics.apis.services.static_data.v1.StaticSectorResponseb\x06proto3')



_STATICSECTORREQUEST = DESCRIPTOR.message_types_by_name['StaticSectorRequest']
_STATICSECTORRESPONSE = DESCRIPTOR.message_types_by_name['StaticSectorResponse']
_LEVEL = DESCRIPTOR.message_types_by_name['Level']
StaticSectorRequest = _reflection.GeneratedProtocolMessageType('StaticSectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorRequest)
  })
_sym_db.RegisterMessage(StaticSectorRequest)

StaticSectorResponse = _reflection.GeneratedProtocolMessageType('StaticSectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORRESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorResponse)
  })
_sym_db.RegisterMessage(StaticSectorResponse)

Level = _reflection.GeneratedProtocolMessageType('Level', (_message.Message,), {
  'DESCRIPTOR' : _LEVEL,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.Level)
  })
_sym_db.RegisterMessage(Level)

_STATICSECTORSERVICE = DESCRIPTOR.services_by_name['StaticSectorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATICSECTORREQUEST._serialized_start=108
  _STATICSECTORREQUEST._serialized_end=189
  _STATICSECTORRESPONSE._serialized_start=191
  _STATICSECTORRESPONSE._serialized_end=313
  _LEVEL._serialized_start=315
  _LEVEL._serialized_end=400
  _STATICSECTORSERVICE._serialized_start=403
  _STATICSECTORSERVICE._serialized_end=570
# @@protoc_insertion_point(module_scope)
