# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xfc\x01\n\x12IntradayRsiRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"f\n\x13IntradayRsiResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayRsiData\"]\n\x0fIntradayRsiData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0b\n\x03rsi\x18\x03 \x01(\x01\x32\xb1\x01\n\x12IntradayRsiService\x12\x9a\x01\n\x0bIntradayRsi\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponseb\x06proto3')



_INTRADAYRSIREQUEST = DESCRIPTOR.message_types_by_name['IntradayRsiRequest']
_INTRADAYRSIRESPONSE = DESCRIPTOR.message_types_by_name['IntradayRsiResponse']
_INTRADAYRSIDATA = DESCRIPTOR.message_types_by_name['IntradayRsiData']
IntradayRsiRequest = _reflection.GeneratedProtocolMessageType('IntradayRsiRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest)
  })
_sym_db.RegisterMessage(IntradayRsiRequest)

IntradayRsiResponse = _reflection.GeneratedProtocolMessageType('IntradayRsiResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponse)
  })
_sym_db.RegisterMessage(IntradayRsiResponse)

IntradayRsiData = _reflection.GeneratedProtocolMessageType('IntradayRsiData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiData)
  })
_sym_db.RegisterMessage(IntradayRsiData)

_INTRADAYRSISERVICE = DESCRIPTOR.services_by_name['IntradayRsiService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYRSIREQUEST._serialized_start=307
  _INTRADAYRSIREQUEST._serialized_end=559
  _INTRADAYRSIRESPONSE._serialized_start=561
  _INTRADAYRSIRESPONSE._serialized_end=663
  _INTRADAYRSIDATA._serialized_start=665
  _INTRADAYRSIDATA._serialized_end=758
  _INTRADAYRSISERVICE._serialized_start=761
  _INTRADAYRSISERVICE._serialized_end=938
# @@protoc_insertion_point(module_scope)
