# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bars.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/tick_analytics/v1/tick_bars.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x95\x03\n\x0fTickBarsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x45\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.BarPrice\x12+\n\x08sampling\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x07 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x08 \x03(\t\x12\x0e\n\x06reject\x18\t \x03(\t\"\xa7\x01\n\x10TickBarsResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04open\x18\x02 \x01(\x01\x12\x0c\n\x04high\x18\x03 \x01(\x01\x12\x0b\n\x03low\x18\x04 \x01(\x01\x12\r\n\x05\x63lose\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04vwap\x18\x08 \x01(\x01*`\n\x08\x42\x61rPrice\x12\x19\n\x15\x42\x41R_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41R_PRICE_TRADE\x10\x01\x12\x11\n\rBAR_PRICE_BID\x10\x02\x12\x11\n\rBAR_PRICE_ASK\x10\x03\x32\x9f\x01\n\x0fTickBarsService\x12\x8b\x01\n\x08TickBars\x12=.systemathics.apis.services.tick_analytics.v1.TickBarsRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickBarsResponse0\x01\x62\x06proto3')

_BARPRICE = DESCRIPTOR.enum_types_by_name['BarPrice']
BarPrice = enum_type_wrapper.EnumTypeWrapper(_BARPRICE)
BAR_PRICE_UNSPECIFIED = 0
BAR_PRICE_TRADE = 1
BAR_PRICE_BID = 2
BAR_PRICE_ASK = 3


_TICKBARSREQUEST = DESCRIPTOR.message_types_by_name['TickBarsRequest']
_TICKBARSRESPONSE = DESCRIPTOR.message_types_by_name['TickBarsResponse']
TickBarsRequest = _reflection.GeneratedProtocolMessageType('TickBarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBARSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBarsRequest)
  })
_sym_db.RegisterMessage(TickBarsRequest)

TickBarsResponse = _reflection.GeneratedProtocolMessageType('TickBarsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBARSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBarsResponse)
  })
_sym_db.RegisterMessage(TickBarsResponse)

_TICKBARSSERVICE = DESCRIPTOR.services_by_name['TickBarsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BARPRICE._serialized_start=856
  _BARPRICE._serialized_end=952
  _TICKBARSREQUEST._serialized_start=279
  _TICKBARSREQUEST._serialized_end=684
  _TICKBARSRESPONSE._serialized_start=687
  _TICKBARSRESPONSE._serialized_end=854
  _TICKBARSSERVICE._serialized_start=955
  _TICKBARSSERVICE._serialized_end=1114
# @@protoc_insertion_point(module_scope)
